<?php
c_include('api/apiAdaptador');

/**
 * Comentarios Api Adapter class for the Mideas Framework.
 *
 * @package		Mideas.Framework
 * @subpackage	Api
 * @since		1.0
 */
class MensajesApiAdaptador extends ApiAdaptador
{
	protected $extension = 'mensajes';
	protected $carpeta = 'ext_mensajes';
	
	protected $elementos_permitidos = array("mensaje");
	
	protected $campos_ignorados_nuevo = array("id","fecha","numero_valoraciones","media_valoracion","visitas");
	protected $campos_multilang = array("titulo","contenido","lugar");
	
	public function __construct($elemento, $accion){
		parent::__construct($elemento, $accion);
		$this->mensajes = array("nuevo_ok"=>__("Se ha enviado el mensaje."), "nuevo_ko"=>__("Se ha producido un error al intentar enviar el mensaje"), "editar_ok"=>__("Se ha modificado el mensaje."), "borrar_ok"=>__("Se ha enviado el mensaje a la papelera de reciclaje"), "restaurar_ok"=>__("Se ha restaurado el mensaje"),"borrar_multiple_ok"=>__("Se han enviado %s mensajes a la papelera de reciclaje"), "restaurar_multiple_ok"=>__("Se han restaurado %s mensajes"));
	}
	
	public function setBorrar(){
		if (empty($this->accion) || $this->accion != 'borrar' || empty($this->elemento) || !Usuario::isLoged() || empty($_POST))
			return false;
			
		$posted = self::sanitize_vars($_POST);
		
		if (empty($posted["id_item"])){
			return $this->error(__("No se ha facilitado el id del item"));
		}
		
		e_include($this->carpeta.'/class/'.$this->elemento);
				
		$class_name = ucfirst($this->elemento);
		
		if (!class_exists($class_name)){
			return false;
		}
		
		if ($posted["multiple"] == true && is_array($posted["id_item"])){
			
			$error = '';
			
			$cuenta_borrados = 0;
			
			foreach ($posted["id_item"] as $id_msg){
				$item = new $class_name();
			
				$item->setid($id_msg);
				
				if ($item = $item->BuscarId()){
					
					if ($item->es_destinatario() || $item->es_propietario()){
						$restaurar = false;
						if ($posted["restaurar"] == "true"){
							$restaurar = true;
						}
						
						if ($item->msgBorrado(true, $restaurar)){
							$cuenta_borrados ++;
						} else {
							$error .= __("Se ha producido un error al intentar borrar el mensaje").'<br>';
						}
					} else {
						$error .= __("El mensaje no se puede borrar").'<br>';
					}
					
				} else {
					$error .= __("No se ha encontrado el mensaje").'<br>';
				}
			}
			
			$mensaje_ok = sprintf($this->mensajes["borrar_multiple_ok"], $cuenta_borrados);
			if ($posted["restaurar"] == "true"){
				$mensaje_ok = sprintf($this->mensajes["restaurar_multiple_ok"], $cuenta_borrados);
			}
			
			if (empty($error)){
				return array("response"=>"ok","response_text"=>$mensaje_ok,"data"=>array("id"=>json_encode($posted["id_item"])));
			} else {
				return $this->error($error);
			}
		} else {
		
			$item = new $class_name();
			
			$item->setid($posted["id_item"]);
			
			if ($item = $item->BuscarId()){
				
				if ($item->es_destinatario() || $item->es_propietario()){
					$restaurar = false;
					$mensaje_ok = $this->mensajes["borrar_ok"];
					if ($posted["restaurar"] == "true"){
						$restaurar = true;
						$mensaje_ok = $this->mensajes["restaurar_ok"];
					}
					
					if ($item->msgBorrado(true, $restaurar)){
						return array("response"=>"ok","response_text"=>$mensaje_ok,"data"=>array("id"=>$posted["id_item"]));
					} else {
						return $this->error(__("Se ha producido un error al intentar borrar el mensaje"));
					}
				} else {
					return $this->error(__("El mensaje no se puede borrar"));
				}
				
			} else {
				return $this->error(__("No se ha encontrado el mensaje"));
			}
		
		}
	}
}